pub struct CoverageRecord { /* private fields */ }Expand description
Coverage report with counts consistent with its lifecycle state.
Implementations
Sourceimpl CoverageRecord
impl CoverageRecord
Sourcepub fn new(
scope: CoverageScope,
relation: Option<GraphRelationKind>,
state: CoverageState,
covered: u64,
omitted: u64,
generation: IndexGeneration,
reason: Option<GraphIdentityText>,
reached_limit: Option<GraphLimitKind>,
) -> Result<Self, GraphContractError>
pub fn new( scope: CoverageScope, relation: Option<GraphRelationKind>, state: CoverageState, covered: u64, omitted: u64, generation: IndexGeneration, reason: Option<GraphIdentityText>, reached_limit: Option<GraphLimitKind>, ) -> Result<Self, GraphContractError>
Construct a coverage row and enforce count/state consistency.
Errors
Returns an error when counts overflow, contradict the selected state, omit a required reason, or claim the pre-publication zero generation.
Sourcepub const fn scope(&self) -> &CoverageScope
pub const fn scope(&self) -> &CoverageScope
Borrow the covered project or path scope.
Sourcepub const fn relation(&self) -> Option<GraphRelationKind>
pub const fn relation(&self) -> Option<GraphRelationKind>
Return the optional relation family covered by this row.
Sourcepub const fn state(&self) -> CoverageState
pub const fn state(&self) -> CoverageState
Return the coverage lifecycle state.
Sourcepub const fn generation(&self) -> IndexGeneration
pub const fn generation(&self) -> IndexGeneration
Return the complete generation associated with this row.
Sourcepub const fn reason(&self) -> Option<&GraphIdentityText>
pub const fn reason(&self) -> Option<&GraphIdentityText>
Borrow the actionable non-complete explanation, when present.
Sourcepub const fn reached_limit(&self) -> Option<GraphLimitKind>
pub const fn reached_limit(&self) -> Option<GraphLimitKind>
Return the product limit reached, when applicable.