pub struct EntityResolutionKey { /* private fields */ }Expand description
One exported canonical key bound to its owning graph entity.
Implementations
Sourceimpl EntityResolutionKey
impl EntityResolutionKey
Sourcepub fn new(
entity: GraphEntityKey,
key: CanonicalResolutionKey,
) -> Result<Self, GraphContractError>
pub fn new( entity: GraphEntityKey, key: CanonicalResolutionKey, ) -> Result<Self, GraphContractError>
Bind one canonical key to its exported entity.
Errors
Returns an error when the entity and key belong to different projects.
Sourcepub const fn entity(&self) -> &GraphEntityKey
pub const fn entity(&self) -> &GraphEntityKey
Borrow the owning entity key.
Sourcepub const fn key(&self) -> &CanonicalResolutionKey
pub const fn key(&self) -> &CanonicalResolutionKey
Borrow the canonical resolver key.