GraphLimits

Struct GraphLimits 

pub struct GraphLimits { /* private fields */ }
Hard bounded retrieval limits accepted by repository graph consumers.

Implementations

Source

impl GraphLimits

pub const MAX_ROWS: u32 = 10_000

Absolute row ceiling for any one graph request.

pub const MAX_OCCURRENCES: u32 = 1_024

Absolute occurrence ceiling for any one logical relation.

pub const MAX_DEPTH: u32 = 64

Absolute traversal-depth ceiling.

pub const MAX_OUTPUT_BYTES: u32

Absolute encoded-output ceiling.

pub fn new( rows: u32, occurrences: u32, depth: u32, output_bytes: u32, ) -> Result<Self, GraphContractError>

Validate result-defining hard limits.

Errors

Returns an error for zero values or values above absolute ceilings.

pub const fn rows(self) -> u32

Return the logical-row limit.

pub const fn occurrences(self) -> u32

Return the per-relation occurrence limit.

pub const fn depth(self) -> u32

Return the traversal-depth limit.

pub const fn output_bytes(self) -> u32

Return the encoded-output byte limit.