pub struct RelationDependencyKey { /* private fields */ }Expand description
One canonical dependency identity bound to its owning logical relation.
Implementations
Sourceimpl RelationDependencyKey
impl RelationDependencyKey
Sourcepub fn new(
relation: LogicalRelationKey,
key: CanonicalResolutionKey,
) -> Result<Self, GraphContractError>
pub fn new( relation: LogicalRelationKey, key: CanonicalResolutionKey, ) -> Result<Self, GraphContractError>
Bind one dependency identity to its logical relation.
Errors
Returns an error when the relation and key belong to different projects.
Sourcepub const fn relation(&self) -> &LogicalRelationKey
pub const fn relation(&self) -> &LogicalRelationKey
Borrow the owning logical-relation key.
Sourcepub const fn key(&self) -> &CanonicalResolutionKey
pub const fn key(&self) -> &CanonicalResolutionKey
Borrow the canonical resolver key.