pub struct GraphLimits { /* private fields */ }Expand description
Hard bounded retrieval limits accepted by repository graph consumers.
Implementations
Sourceimpl GraphLimits
impl GraphLimits
Sourcepub const MAX_OCCURRENCES: u32 = 1_024
pub const MAX_OCCURRENCES: u32 = 1_024
Absolute occurrence ceiling for any one logical relation.
Sourcepub const MAX_OUTPUT_BYTES: u32
pub const MAX_OUTPUT_BYTES: u32
Absolute encoded-output ceiling.
Sourcepub fn new(
rows: u32,
occurrences: u32,
depth: u32,
output_bytes: u32,
) -> Result<Self, GraphContractError>
pub fn new( rows: u32, occurrences: u32, depth: u32, output_bytes: u32, ) -> Result<Self, GraphContractError>
Validate result-defining hard limits.
Errors
Returns an error for zero values or values above absolute ceilings.
Sourcepub const fn occurrences(self) -> u32
pub const fn occurrences(self) -> u32
Return the per-relation occurrence limit.
Sourcepub const fn output_bytes(self) -> u32
pub const fn output_bytes(self) -> u32
Return the encoded-output byte limit.